# Generated by Django 4.2.23 on 2026-01-07 04:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('markettracker', '0009_alter_mttasklog_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='discordmessage',
            name='contract_restocked_alert_header',
            field=models.CharField(default='✅ Contracts restocked', help_text='Header used for contracts restock alerts', max_length=200),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='contract_restocked_ping_choice',
            field=models.CharField(blank=True, help_text='Special ping target: none, here, everyone', max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='contract_restocked_ping_group',
            field=models.ForeignKey(blank=True, help_text='Discord role (from AA group) to ping for contracts restocked', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='markettracker_contract_restocked_pings', to='auth.group'),
        ),
    ]
