# Generated by Django 4.2.23 on 2025-12-19 19:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('markettracker', '0008_mttasklog'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mttasklog',
            options={'default_permissions': (), 'ordering': ['-created']},
        ),
    ]
