# Generated by Django 4.2.23 on 2025-08-15 00:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('markettracker', '0002_discordmessage_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='MarketOrderSnapshot',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order_id', models.BigIntegerField(unique=True)),
                ('structure_id', models.BigIntegerField()),
                ('price', models.FloatField()),
                ('volume_remain', models.IntegerField()),
                ('is_buy_order', models.BooleanField(default=False)),
                ('issued', models.DateTimeField()),
                ('tracked_item', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='order_snapshots', to='markettracker.trackeditem')),
            ],
            options={
                'default_permissions': (),
                'indexes': [models.Index(fields=['tracked_item'], name='markettrack_tracked_26db9c_idx'), models.Index(fields=['structure_id'], name='markettrack_structu_d1331f_idx'), models.Index(fields=['is_buy_order'], name='markettrack_is_buy__872f1c_idx')],
            },
        ),
    ]
