# Generated by Django 4.2.23 on 2025-12-08 14:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('markettracker', '0006_discordmessage_item_restocked_alert_header_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='contractsnapshot',
            name='date_completed',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
